==> spip_4.0.4.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reiniciar',
	'boxstr_close' => 'Fechar',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Caixa de diálogo',
	'boxstr_dialog_title_medias' => 'Exibição de uma mídia',
	'boxstr_loading' => 'Carregando...',
	'boxstr_next' => 'Próxima',
	'boxstr_press_escape_to_close' => 'Pressione ’Esc’ para fechar',
	'boxstr_previous' => 'Anterior',
	'boxstr_slideshowStart' => 'Slideshow',
	'boxstr_slideshowStop' => 'Parar',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indique os elementos-alvo que irão acionar o box. (Expressão CSS ou âmbito jQuery)',
	'explication_selecteur_galerie' => 'Indique os elementos-alvo a serem agrupados na galeria. (Expressão CSS ou âmbito jQuery)',
	'explication_splash_url' => 'Indique o URL do arquivo a ser exibido em um box no primeiro acesso no site público.',
	'explication_traiter_toutes_images' => 'Inserir um box em todas as imagens?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Modo escuro',
	'info_box_lity_nom_skin__simple_white' => 'Modo claro',
	'info_box_lity_nom_skin_fancybox' => 'Tipo Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'Tipo Thickbox',

	// L
	'label_active' => 'Ativar o box multimídia no site público',
	'label_apparence' => 'Aparência',
	'label_aucun_style' => 'Não insirir nenhum tema padrão',
	'label_choix_transition_elastic' => 'Elástico',
	'label_choix_transition_fade' => 'Dissolvido',
	'label_choix_transition_none' => 'Sem efeito de transição',
	'label_maxheight' => 'Altura máxima (% ou px)',
	'label_maxwidth' => 'Largura máxima (% ou px)',
	'label_minheight' => 'Altura mínima (% ou px)',
	'label_minwidth' => 'Largura mínima (% ou px)',
	'label_opacite' => 'Opacidade do fundo',
	'label_selecteur_commun' => 'Em geral',
	'label_selecteur_galerie' => 'Na galeria',
	'label_skin' => 'Tema visual',
	'label_slideshow_speed' => 'Tempo de exibição das fotos do slideshow (ms)',
	'label_speed' => 'Velocidade da transição (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Altura (% ou px)',
	'label_splash_url' => 'URL a ser exibida',
	'label_splash_width' => 'Largura (% ou px)',
	'label_traiter_toutes_images' => 'Imagens',
	'label_transition' => 'Transição entre exibições',

	// T
	'titre_menu_box' => 'Box Multimídia',
	'titre_page_configurer_box' => 'Configuração do Box Multimídia'
);

==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reiniciar',
	'boxstr_close' => 'Fechar',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Caixa de diálogo',
	'boxstr_dialog_title_medias' => 'Exibição de uma mídia',
	'boxstr_loading' => 'Carregando...',
	'boxstr_next' => 'Próxima',
	'boxstr_press_escape_to_close' => 'Pressione ’Esc’ para fechar',
	'boxstr_previous' => 'Anterior',
	'boxstr_slideshowStart' => 'Slideshow',
	'boxstr_slideshowStop' => 'Parar',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indique os elementos-alvo que irão acionar o box. (Expressão CSS ou âmbito jQuery)',
	'explication_selecteur_galerie' => 'Indique os elementos-alvo a serem agrupados na galeria. (Expressão CSS ou âmbito jQuery)',
	'explication_splash_url' => 'Indique o URL do arquivo a ser exibido em um box no primeiro acesso no site público.',
	'explication_traiter_toutes_images' => 'Inserir um box em todas as imagens?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Modo escuro',
	'info_box_lity_nom_skin__simple_white' => 'Modo claro',
	'info_box_lity_nom_skin_fancybox' => 'Tipo Fancybox',
	'info_box_lity_nom_skin_thickbox' => 'Tipo Thickbox',

	// L
	'label_active' => 'Ativar o box multimídia no site público',
	'label_apparence' => 'Aparência',
	'label_aucun_style' => 'Não insirir nenhum tema padrão',
	'label_choix_transition_elastic' => 'Elástico',
	'label_choix_transition_fade' => 'Dissolvido',
	'label_choix_transition_none' => 'Sem efeito de transição',
	'label_defaultcaptionstate' => 'Legenda das imagens',
	'label_defaultcaptionstate_expanded' => 'Completa',
	'label_defaultcaptionstate_min' => 'Abreviada',
	'label_maxheight' => 'Altura máxima (% ou px)',
	'label_maxwidth' => 'Largura máxima (% ou px)',
	'label_minheight' => 'Altura mínima (% ou px)',
	'label_minwidth' => 'Largura mínima (% ou px)',
	'label_opacite' => 'Opacidade do fundo',
	'label_selecteur_commun' => 'Em geral',
	'label_selecteur_galerie' => 'Na galeria',
	'label_skin' => 'Tema visual',
	'label_slideshow_speed' => 'Tempo de exibição das fotos do slideshow (ms)',
	'label_speed' => 'Velocidade da transição (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Altura (% ou px)',
	'label_splash_url' => 'URL a ser exibida',
	'label_splash_width' => 'Largura (% ou px)',
	'label_traiter_toutes_images' => 'Imagens',
	'label_transition' => 'Transição entre exibições',

	// T
	'titre_menu_box' => 'Box Multimídia',
	'titre_page_configurer_box' => 'Configuração do Box Multimídia'
);
